@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -426,7 +426,7 @@ class DockWindow(HasPrivateTraits):
             from feature_bar import FeatureBar
 
             self._feature_bar = fb = FeatureBar(parent=self.control)
-            fb.on_trait_change(self._feature_bar_closed, "completed")
+            fb.observe(self._feature_bar_closed, "completed")
 
         fb.dock_control = dock_control
         fb.show()
@@ -435,7 +435,7 @@ class DockWindow(HasPrivateTraits):
     #  Handles closing the feature bar:
     # ---------------------------------------------------------------------------
 
-    def _feature_bar_closed(self):
+    def _feature_bar_closed(self, event):
         fb = self._feature_bar
         fb.dock_control.feature_bar_closed()
         fb.hide()
