@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -68,16 +68,10 @@ class MTextField(HasTraits):
     def _add_event_listeners(self):
         """ Set up toolkit-specific bindings for events """
         super(MTextField, self)._add_event_listeners()
-        self.on_trait_change(
-            self._update_text_updated, "update_text", dispatch="ui"
-        )
-        self.on_trait_change(
-            self._placeholder_updated, "placeholder", dispatch="ui"
-        )
-        self.on_trait_change(self._echo_updated, "echo", dispatch="ui")
-        self.on_trait_change(
-            self._read_only_updated, "read_only", dispatch="ui"
-        )
+        self.observe(self._update_text_updated, "update_text", dispatch="ui")
+        self.observe(self._placeholder_updated, "placeholder", dispatch="ui")
+        self.observe(self._echo_updated, "echo", dispatch="ui")
+        self.observe(self._read_only_updated, "read_only", dispatch="ui")
         if self.control is not None:
             if self.update_text == "editing_finished":
                 self._observe_control_editing_finished()
@@ -91,22 +85,22 @@ class MTextField(HasTraits):
                 self._observe_control_editing_finished(remove=True)
             else:
                 self._observe_control_value(remove=True)
-        self.on_trait_change(
+        self.observe(
             self._update_text_updated,
             "update_text",
             dispatch="ui",
             remove=True,
         )
-        self.on_trait_change(
+        self.observe(
             self._placeholder_updated,
             "placeholder",
             dispatch="ui",
             remove=True,
         )
-        self.on_trait_change(
+        self.observe(
             self._echo_updated, "echo", dispatch="ui", remove=True
         )
-        self.on_trait_change(
+        self.observe(
             self._read_only_updated, "read_only", dispatch="ui", remove=True
         )
         super(MTextField, self)._remove_event_listeners()
@@ -120,50 +114,50 @@ class MTextField(HasTraits):
 
     def _get_control_placeholder(self):
         """ Toolkit specific method to set the control's placeholder. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _set_control_placeholder(self, placeholder):
         """ Toolkit specific method to set the control's placeholder. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_control_echo(self):
         """ Toolkit specific method to get the control's echo. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _set_control_echo(self, echo):
         """ Toolkit specific method to set the control's echo. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_control_read_only(self):
         """ Toolkit specific method to get the control's read_only state. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _set_control_read_only(self, read_only):
         """ Toolkit specific method to set the control's read_only state. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _observe_control_editing_finished(self, remove=False):
         """ Change observation of whether editing is finished. """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     # Trait change handlers --------------------------------------------------
 
-    def _placeholder_updated(self):
+    def _placeholder_updated(self, event):
         if self.control is not None:
             self._set_control_placeholder(self.placeholder)
 
-    def _echo_updated(self):
+    def _echo_updated(self, event):
         if self.control is not None:
             self._set_control_echo(self.echo)
 
-    def _read_only_updated(self):
+    def _read_only_updated(self, event):
         if self.control is not None:
             self._set_control_read_only(self.read_only)
 
-    def _update_text_updated(self, new):
+    def _update_text_updated(self, event):
         """ Change how we listen to for updates to text value. """
         if self.control is not None:
-            if new == "editing_finished":
+            if event.new == "editing_finished":
                 self._observe_control_value(remove=True)
                 self._observe_control_editing_finished()
             else:
