@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -31,7 +31,7 @@ from traits.api import (
     Tuple,
     Undefined,
     Vetoable,
-    on_trait_change,
+    observe,
 )
 
 from .application import Application
@@ -258,12 +258,8 @@ class GUIApplication(Application):
 
     def _about_dialog_default(self):
         """ Default AboutDialog """
-        from sys import version_info
-
-        if (version_info.major, version_info.minor) >= (3, 2):
-            from html import escape
-        else:
-            from cgi import escape
+        from html import escape
+        
         from pyface.about_dialog import AboutDialog
 
         additions = [
@@ -284,22 +280,24 @@ class GUIApplication(Application):
 
     # Trait listeners --------------------------------------------------------
 
-    @on_trait_change("windows:activated")
-    def _on_activate_window(self, window, trait, old, new):
+    @observe("windows:items:activated")
+    def _on_activate_window(self, event):
         """ Listener that tracks currently active window.
         """
+        window = event.object
         if window in self.windows:
             self.active_window = window
 
-    @on_trait_change("windows:deactivated")
-    def _on_deactivate_window(self, window, trait, old, new):
+    @observe("windows:items:deactivated")
+    def _on_deactivate_window(self, event):
         """ Listener that tracks currently active window.
         """
         self.active_window = None
 
-    @on_trait_change("windows:closed")
-    def _on_window_closed(self, window, trait, old, new):
+    @observe("windows:items:closed")
+    def _on_window_closed(self, event):
         """ Listener that ensures window handles are released when closed.
         """
+        window = event.object
         if window in self.windows:
             self.windows.remove(window)
