@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,14 +9,11 @@
 # Thanks for using Enthought open source!
 """ The interface for an image resource. """
 
-try:
-    from collections.abc import Sequence
-except ImportError:  # Python 3.8 deprecation
-    from collections import Sequence
+from collections.abc import Sequence
 
 from pyface.resource_manager import resource_manager
 from pyface.resource.resource_path import resource_module, resource_path
-from traits.api import Interface, List, Str
+from traits.api import HasTraits, Interface, List, Str
 
 
 class IImageResource(Interface):
@@ -116,7 +113,7 @@ class IImageResource(Interface):
         """
 
 
-class MImageResource(object):
+class MImageResource(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IImageResource interface.
 
