@@ -1,22 +1,19 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ The interface for a dialog that allows the user to open/save files etc. """
 
-# Enthought library imports.
-from traits.api import Any, Bool, Int, Str
 
-# Local imports.
+from traits.api import Any, Bool, HasTraits, Int, Str
+
+
 from pyface.i_dialog import IDialog
 
 
@@ -24,16 +21,16 @@ class IProgressDialog(IDialog):
     """ A simple progress dialog window which allows itself to be updated
     """
 
-    #### 'IProgressDialog' interface ##################################
+    # 'IProgressDialog' interface ---------------------------------#
 
     #: The message to display in the dialog
-    message = Str
+    message = Str()
 
     #: The minimum progress value
-    min = Int
+    min = Int()
 
     #: The maximum progress value
-    max = Int
+    max = Int()
 
     #: The margin around the progress bar
     margin = Int(5)
@@ -48,11 +45,11 @@ class IProgressDialog(IDialog):
     show_percent = Bool(False)
 
     #: Label for the 'cancel' button
-    cancel_button_label = Str
+    cancel_button_label = Str()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IProgressDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def update(self, value):
         """ Update the progress bar to the desired value
@@ -77,7 +74,7 @@ class IProgressDialog(IDialog):
         """
 
 
-class MProgressDialog(object):
+class MProgressDialog(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IProgressDialog interface.
 
@@ -86,11 +83,11 @@ class MProgressDialog(object):
 
     #: The progress bar toolkit object
     # XXX why not the control?
-    progress_bar = Any
+    progress_bar = Any()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IWindow' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def open(self):
         """ Open the dialog """
@@ -100,9 +97,9 @@ class MProgressDialog(object):
 
         super(MProgressDialog, self).open()
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'IProgressDialog' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def update(self, value):
         """ Update the progress bar to the desired value
