@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -39,8 +39,8 @@ class IWidget(Interface):
     def show(self, visible):
         """ Show or hide the widget.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         visible : bool
             Visible should be ``True`` if the widget should be shown.
         """
@@ -48,12 +48,32 @@ class IWidget(Interface):
     def enable(self, enabled):
         """ Enable or disable the widget.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         enabled : bool
             The enabled state to set the widget to.
         """
 
+    def focus(self):
+        """ Set the keyboard focus to this widget.
+        """
+
+    def has_focus(self):
+        """ Does the widget currently have keyboard focus?
+
+        Returns
+        -------
+        focus_state : bool
+            Whether or not the widget has keyboard focus.
+        """
+
+    def create(self):
+        """ Creates the toolkit specific control.
+
+        This method should create the control and assign it to the
+        :py:attr:``control`` trait.
+        """
+
     def destroy(self):
         """ Destroy the control if it exists. """
 
@@ -61,13 +81,6 @@ class IWidget(Interface):
     # Protected 'IWidget' interface.
     # ------------------------------------------------------------------------
 
-    def _create(self):
-        """ Creates the toolkit specific control.
-
-        This method should create the control and assign it to the
-        :py:attr:``control`` trait.
-        """
-
     def _create_control(self, parent):
         """ Create toolkit specific control that represents the widget.
 
@@ -90,11 +103,18 @@ class IWidget(Interface):
         """ Remove toolkit-specific bindings for events """
 
 
-class MWidget(object):
+class MWidget(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IWidget interface.
     """
 
+    def create(self):
+        """ Creates the toolkit specific control.
+
+        The default implementation simply calls _create()
+        """
+        self._create()
+
     # ------------------------------------------------------------------------
     # Protected 'IWidget' interface.
     # ------------------------------------------------------------------------
@@ -122,7 +142,7 @@ class MWidget(object):
         control : toolkit control
             A control for the widget.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _add_event_listeners(self):
         """ Set up toolkit-specific bindings for events """
