@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -25,7 +25,7 @@ class PreferencePage(HasTraits):
     def create_control(self, parent):
         """ Creates the toolkit-specific control for the page. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def restore_defaults(self):
         """ Restore the default preferences. """
