@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,8 +15,5 @@ if qt_api == "pyqt":
 elif qt_api == "pyqt5":
     from PyQt5.QtOpenGL import *
 
-elif qt_api == "pyside2":
-    from PySide2.QtOpenGL import *
-
 else:
-    from PySide.QtOpenGL import *
+    from PySide2.QtOpenGL import *
