@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,15 +12,7 @@ from . import qt_api
 if qt_api == "pyqt":
     from PyQt4.QtScript import *
 
-elif qt_api == "pyqt5":
-    import warnings
-
-    warnings.warn(DeprecationWarning("QtScript is not supported in PyQt5"))
-
-elif qt_api == "pyside2":
-    import warnings
-
-    warnings.warn(DeprecationWarning("QtScript is not supported in PyQt5"))
-
 else:
-    from PySide.QtScript import *
+    import warnings
+
+    warnings.warn(DeprecationWarning("QtScript is not supported in PyQt5/PySide2"))
