@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -35,12 +35,7 @@ from traits.api import (
     provides,
 )
 
-if sys.version_info[:2] < (3, 3):
-    import timeit
-
-    perf_counter = timeit.default_timer
-else:
-    perf_counter = time.perf_counter
+perf_counter = time.perf_counter
 
 
 class ITimer(Interface):
@@ -143,7 +138,7 @@ class BaseTimer(ABCHasTraits):
     expire = Either(None, Float)
 
     #: Property that controls the state of the timer.
-    active = Property(Bool, depends_on="_active")
+    active = Property(Bool, observe="_active")
 
     # Private interface ------------------------------------------------------
 
