@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -96,7 +96,7 @@ class NodeManager(HasPrivateTraits):
                 node_type = None
 
         if node_type is None:
-            logger.warn("no node type for %s" % str(node))
+            logger.warning("no node type for %s" % str(node))
 
         return node_type
 
