@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,7 +17,7 @@
 from pyface.qt import QtCore, QtGui
 
 
-from traits.api import Bool, Enum, Instance, Str, Tuple
+from traits.api import Bool, Enum, Instance, List, Str, Tuple
 
 
 from pyface.image_cache import ImageCache
@@ -55,6 +55,9 @@ class ToolBarManager(ActionManager):
     # Cache of tool images (scaled to the appropriate size).
     _image_cache = Instance(ImageCache)
 
+    #: Keep track of all created toolbars in order to properly dispose of them
+    _toolbars = List()
+
     # ------------------------------------------------------------------------
     # 'object' interface.
     # ------------------------------------------------------------------------
@@ -87,6 +90,7 @@ class ToolBarManager(ActionManager):
 
         # Create the control.
         tool_bar = _ToolBar(self, parent)
+        self._toolbars.append(tool_bar)
         tool_bar.setObjectName(self.id)
         tool_bar.setWindowTitle(self.name)
 
@@ -108,6 +112,17 @@ class ToolBarManager(ActionManager):
 
         return tool_bar
 
+    # ------------------------------------------------------------------------
+    # 'ActionManager' interface.
+    # ------------------------------------------------------------------------
+
+    def destroy(self):
+        while self._toolbars:
+            toolbar = self._toolbars.pop()
+            toolbar.dispose()
+
+        super(ToolBarManager, self).destroy()
+
     # ------------------------------------------------------------------------
     # Private interface.
     # ------------------------------------------------------------------------
@@ -121,7 +136,7 @@ class ToolBarManager(ActionManager):
                 # Is a separator required?
                 if previous_non_empty_group is not None and group.separator:
                     separator = tool_bar.addSeparator()
-                    group.on_trait_change(
+                    group.observe(
                         self._separator_visibility_method(separator), "visible"
                     )
 
@@ -139,7 +154,7 @@ class ToolBarManager(ActionManager):
 
     def _separator_visibility_method(self, separator):
         """ Method to return closure to set visibility of group separators. """
-        return lambda visible: separator.setVisible(visible)
+        return lambda event: separator.setVisible(event.new)
 
 
 class _ToolBar(QtGui.QToolBar):
@@ -154,32 +169,49 @@ class _ToolBar(QtGui.QToolBar):
 
         QtGui.QToolBar.__init__(self, parent)
 
+        # List of tools
+        self.tools = []
+
         # Listen for changes to the tool bar manager's enablement and
         # visibility.
         self.tool_bar_manager = tool_bar_manager
 
-        self.tool_bar_manager.on_trait_change(
+        self.tool_bar_manager.observe(
             self._on_tool_bar_manager_enabled_changed, "enabled"
         )
 
-        self.tool_bar_manager.on_trait_change(
+        self.tool_bar_manager.observe(
             self._on_tool_bar_manager_visible_changed, "visible"
         )
 
         return
 
+    def dispose(self):
+        self.tool_bar_manager.observe(
+            self._on_tool_bar_manager_enabled_changed, "enabled", remove=True
+        )
+        self.tool_bar_manager.observe(
+            self._on_tool_bar_manager_visible_changed, "visible", remove=True
+        )
+        # Removes event listeners from downstream tools and clears their
+        # references
+        for item in self.tools:
+            item.dispose()
+
+        self.tools = []
+
     # ------------------------------------------------------------------------
     # Trait change handlers.
     # ------------------------------------------------------------------------
 
-    def _on_tool_bar_manager_enabled_changed(self, obj, trait_name, old, new):
+    def _on_tool_bar_manager_enabled_changed(self, event):
         """ Dynamic trait change handler. """
 
-        self.setEnabled(new)
+        self.setEnabled(event.new)
 
-    def _on_tool_bar_manager_visible_changed(self, obj, trait_name, old, new):
+    def _on_tool_bar_manager_visible_changed(self, event):
         """ Dynamic trait change handler. """
 
-        self.setVisible(new)
+        self.setVisible(event.new)
 
         return
