@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -93,6 +93,11 @@ class CodeWidget(QtGui.QPlainTextEdit):
         )
         self.backspace_key = QtGui.QKeySequence(QtCore.Qt.Key_Backspace)
 
+    def _remove_event_listeners(self):
+        self.blockCountChanged.disconnect(self.update_line_number_width)
+        self.updateRequest.disconnect(self.update_line_numbers)
+        self.cursorPositionChanged.disconnect(self.highlight_current_line)
+
     def lines(self):
         """ Return the number of lines.
         """
@@ -468,7 +473,12 @@ class CodeWidget(QtGui.QPlainTextEdit):
         style = self.style()
         opt = QtGui.QStyleOptionHeader()
         font_metrics = QtGui.QFontMetrics(self.document().defaultFont())
-        width = font_metrics.width(" ") * 80
+        # QFontMetrics.width() is deprecated and Qt docs suggest using
+        # horizontalAdvance() instead, but is only available since Qt 5.11
+        if QtCore.__version_info__ >= (5, 11):
+            width = font_metrics.horizontalAdvance(" ") * 80
+        else:
+            width = font_metrics.width(" ") * 80
         width += self.line_number_widget.sizeHint().width()
         width += self.status_widget.sizeHint().width()
         width += style.pixelMetric(QtGui.QStyle.PM_ScrollBarExtent, opt, self)
@@ -588,6 +598,24 @@ class AdvancedCodeWidget(QtGui.QWidget):
 
         self.setLayout(layout)
 
+    def _remove_event_listeners(self):
+        self.code.selectionChanged.disconnect(self._update_replace_enabled)
+
+        self.find.line_edit.returnPressed.disconnect(self.find_next)
+        self.find.next_button.clicked.disconnect(self.find_next)
+        self.find.prev_button.clicked.disconnect(self.find_prev)
+
+        self.replace.line_edit.returnPressed.disconnect(self.find_next)
+        self.replace.line_edit.textChanged.disconnect(
+            self._update_replace_all_enabled
+        )
+        self.replace.next_button.clicked.disconnect(self.find_next)
+        self.replace.prev_button.clicked.disconnect(self.find_prev)
+        self.replace.replace_button.clicked.disconnect(self.replace_next)
+        self.replace.replace_all_button.clicked.disconnect(self.replace_all)
+
+        self.code._remove_event_listeners()
+
     def lines(self):
         """ Return the number of lines.
         """
