@@ -1,5 +1,5 @@
 # (C) Copyright 2007 Riverbank Computing Limited
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -113,6 +113,8 @@ class PythonEditor(MPythonEditor, Widget):
                 self._on_dirty_changed
             )
             self.control.code.textChanged.disconnect(self._on_text_changed)
+            # Disconnect signals from control and other dependent widgets
+            self.control._remove_event_listeners()
 
             if self._event_filter is not None:
                 self.control.code.removeEventFilter(self._event_filter)
