@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,7 +12,7 @@ from itertools import combinations
 import logging
 
 
-from pyface.qt import QtCore, QtGui
+from pyface.qt import QtCore, QtGui, is_qt4
 
 
 from traits.api import Any, HasTraits
@@ -154,8 +154,9 @@ class MainWindowLayout(HasTraits):
                     sublayout, q_dock_area, _toplevel_call=False
                 )
 
-        # Remove the fixed sizes once Qt activates the layout.
-        QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
+        if is_qt4:
+            # Remove the fixed sizes once Qt activates the layout.
+            QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
 
     def set_layout_for_area(
         self, layout, q_dock_area, _toplevel_added=False, _toplevel_call=True
@@ -227,9 +228,10 @@ class MainWindowLayout(HasTraits):
         else:
             raise MainWindowLayoutError("Unknown layout item %r" % layout)
 
-        # Remove the fixed sizes once Qt activates the layout.
-        if _toplevel_call:
-            QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
+        if is_qt4:
+            # Remove the fixed sizes once Qt activates the layout.
+            if _toplevel_call:
+                QtCore.QTimer.singleShot(0, self._reset_fixed_sizes)
 
     # ------------------------------------------------------------------------
     # 'MainWindowLayout' abstract interface.
@@ -238,12 +240,12 @@ class MainWindowLayout(HasTraits):
     def _get_dock_widget(self, pane):
         """ Returns the QDockWidget associated with a PaneItem.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_pane(self, dock_widget):
         """ Returns a PaneItem for a QDockWidget.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     # ------------------------------------------------------------------------
     # Private interface.
@@ -309,10 +311,14 @@ class MainWindowLayout(HasTraits):
                     "Cannot retrieve dock widget for pane %r" % layout.id
                 )
             else:
-                if layout.width > 0:
-                    dock_widget.widget().setFixedWidth(layout.width)
-                if layout.height > 0:
-                    dock_widget.widget().setFixedHeight(layout.height)
+                if is_qt4:
+                    if layout.width > 0:
+                        dock_widget.widget().setFixedWidth(layout.width)
+                    if layout.height > 0:
+                        dock_widget.widget().setFixedHeight(layout.height)
+                else:
+                    sizeHint = lambda : QtCore.QSize(layout.width, layout.height)
+                    dock_widget.widget().sizeHint = sizeHint
             return dock_widget
 
         elif isinstance(layout, LayoutContainer):
