@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,16 +13,18 @@ import sys
 
 from pyface.tasks.i_editor_area_pane import IEditorAreaPane, MEditorAreaPane
 from traits.api import (
+    Any,
     Bool,
     cached_property,
     Callable,
     Dict,
     Instance,
     List,
-    on_trait_change,
+    observe,
     Property,
     provides,
     Str,
+    Tuple,
 )
 from pyface.qt import is_qt4, QtCore, QtGui
 from pyface.action.api import Action, Group, MenuManager
@@ -69,10 +71,15 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
 
     # Private interface ---------------------------------------------------
 
+    #: A list of connected Qt signals to be removed before destruction.
+    #: First item in the tuple is the Qt signal. The second item is the event
+    #: handler.
+    _connections_to_remove = List(Tuple(Any, Callable))
+
     _private_drop_handlers = List(IDropHandler)
     _all_drop_handlers = Property(
         List(IDropHandler),
-        depends_on=["drop_handlers", "_private_drop_handlers"],
+        observe=["drop_handlers", "_private_drop_handlers"],
     )
 
     def __private_drop_handlers_default(self):
@@ -127,6 +134,14 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
         for editor in self.editors[:]:
             self.remove_editor(editor)
 
+        while self._connections_to_remove:
+            signal, handler = self._connections_to_remove.pop()
+            signal.disconnect(handler)
+
+        # Remove reference to active tabwidget so that it can be deleted
+        # together with the main control
+        self.active_tabwidget = None
+
         super(SplitEditorAreaPane, self).destroy()
 
     # ------------------------------------------------------------------------
@@ -304,17 +319,29 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
             prev_seq = "Ctrl+PgUp"
         shortcut = QtGui.QShortcut(QtGui.QKeySequence(next_seq), self.control)
         shortcut.activated.connect(self._next_tab)
+        self._connections_to_remove.append(
+            (shortcut.activated, self._next_tab)
+        )
         shortcut = QtGui.QShortcut(QtGui.QKeySequence(prev_seq), self.control)
         shortcut.activated.connect(self._previous_tab)
+        self._connections_to_remove.append(
+            (shortcut.activated, self._previous_tab)
+        )
 
         # Add shortcuts for switching to a specific tab.
         mod = "Ctrl+" if sys.platform == "darwin" else "Alt+"
         mapper = QtCore.QSignalMapper(self.control)
         mapper.mapped.connect(self._activate_tab)
+        self._connections_to_remove.append(
+            (mapper.mapped, self._activate_tab)
+        )
         for i in range(1, 10):
             sequence = QtGui.QKeySequence(mod + str(i))
             shortcut = QtGui.QShortcut(sequence, self.control)
             shortcut.activated.connect(mapper.map)
+            self._connections_to_remove.append(
+                (shortcut.activated, mapper.map)
+            )
             mapper.setMapping(shortcut, i - 1)
 
     def _activate_tab(self, index):
@@ -352,13 +379,15 @@ class SplitEditorAreaPane(TaskPane, MEditorAreaPane):
 
     # Trait change handlers ------------------------------------------------
 
-    @on_trait_change("editors:[dirty, name]")
-    def _update_label(self, editor, name, new):
+    @observe("editors:items:[dirty, name]")
+    def _update_label(self, event):
+        editor = event.object
         index = self.active_tabwidget.indexOf(editor.control)
         self.active_tabwidget.setTabText(index, self._get_label(editor))
 
-    @on_trait_change("editors:tooltip")
-    def _update_tooltip(self, editor, name, new):
+    @observe("editors:items:tooltip")
+    def _update_tooltip(self, event):
+        editor = event.object
         index = self.active_tabwidget.indexOf(editor.control)
         self.active_tabwidget.setTabToolTip(index, self._get_label(editor))
 
