@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -29,7 +29,6 @@ from pyface.util.testing import skip_if_no_traitsui
 is_qt = toolkit_object.toolkit == "qt4"
 if is_qt:
     from pyface.qt import qt_api
-is_pyqt5 = is_qt and qt_api == "pyqt5"
 
 
 class MyClass(HasStrictTraits):
@@ -54,10 +53,7 @@ class MyClass(HasStrictTraits):
         return True
 
 
-@unittest.skipIf(
-    is_pyqt5, "ModalDialogTester not working on pyqt5. Issue #302"
-)
-class TestModalDialogTester(unittest.TestCase, GuiTestAssistant):
+class TestModalDialogTester(GuiTestAssistant, unittest.TestCase):
     """ Tests for the modal dialog tester. """
 
     # Tests ----------------------------------------------------------------
