@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -31,4 +31,4 @@ class ContentProvider(HasTraits):
 
         """
 
-        raise NotImplementedError
+        raise NotImplementedError()
