@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -253,104 +253,104 @@ class MWorkbenchWindowLayout(HasTraits):
     def activate_editor(self, editor):
         """ Activate an editor. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def activate_view(self, view):
         """ Activate a view. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def add_editor(self, editor, title):
         """ Add an editor. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def add_view(self, view, position=None, relative_to=None, size=(-1, -1)):
         """ Add a view. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def close_editor(self, editor):
         """ Close an editor. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def close_view(self, view):
         """ Close a view. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def close(self):
         """ Close the entire window layout. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def create_initial_layout(self, parent):
         """ Create the initial window layout. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def contains_view(self, view):
         """ Return True if the view exists in the window layout. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def hide_editor_area(self):
         """ Hide the editor area. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def hide_view(self, view):
         """ Hide a view. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def refresh(self):
         """ Refresh the window layout to reflect any changes. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def reset_editors(self):
         """ Activate the first editor in every group. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def reset_views(self):
         """ Activate the first view in every region. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def show_editor_area(self):
         """ Show the editor area. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def show_view(self, view):
         """ Show a view. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     # Methods for saving and restoring the layout -------------------------#
 
     def get_view_memento(self):
         """ Returns the state of the views. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def set_view_memento(self, memento):
         """ Restores the state of the views. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def get_editor_memento(self):
         """ Returns the state of the editors. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def set_editor_memento(self, memento):
         """ Restores the state of the editors. """
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def get_toolkit_memento(self):
         """ Return any toolkit-specific data that should be part of the memento.
