@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -54,7 +54,7 @@ class Grid(wxGrid):
         #
         # fixme: We should create a default model if one is not supplied.
         self.SetTable(model._grid_table_base, True)
-        model.on_trait_change(self._on_model_changed, "model_changed")
+        model.observe(self._on_model_changed, "model_changed")
 
         self.Bind(wx.grid.EVT_GRID_CELL_CHANGE, self._on_cell_change)
         self.Bind(wx.grid.EVT_GRID_SELECT_CELL, self._on_select_cell)
@@ -216,9 +216,9 @@ class Grid(wxGrid):
     # Trait event handlers.
     # ------------------------------------------------------------------------
 
-    def _on_model_changed(self, message):
+    def _on_model_changed(self, event):
         """ Called when the model has changed. """
-
+        message = event.new
         self.BeginBatch()
         self.ProcessTableMessage(message)
         self.EndBatch()
